@@ -116,7 +116,7 @@ class CommitMessageEditor(QtWidgets.QFrame):
         self.amend_action = self.actions_menu.addAction(N_('Amend Last Commit'))
         self.amend_action.setIcon(icons.edit())
         self.amend_action.setCheckable(True)
-        self.amend_action.setShortcut(hotkeys.AMEND)
+        self.amend_action.setShortcuts(hotkeys.AMEND)
         self.amend_action.setShortcutContext(Qt.ApplicationShortcut)
 
         # Bypass hooks
@@ -196,8 +196,6 @@ class CommitMessageEditor(QtWidgets.QFrame):
             # description starts at line 2
             lambda row, col: self.cursor_changed.emit(row + 2, col)
         )
-
-        # pylint: disable=no-member
         self.summary.textChanged.connect(self.commit_summary_changed)
         self.description.textChanged.connect(self._commit_message_changed)
         self.description.leave.connect(self.focus_summary)
@@ -575,7 +573,6 @@ class CommitMessageEditor(QtWidgets.QFrame):
         self.description.highlighter.enable(enabled)
 
 
-# pylint: disable=too-many-ancestors
 class CommitSummaryLineEdit(SpellCheckLineEdit):
     """Text input field for the commit summary"""
 
@@ -626,7 +623,6 @@ class CommitSummaryLineEdit(SpellCheckLineEdit):
         SpellCheckLineEdit.keyPressEvent(self, event)
 
 
-# pylint: disable=too-many-ancestors
 class CommitMessageTextEdit(SpellCheckTextEdit):
     leave = Signal()
 
