@@ -1,8 +1,8 @@
 """Provides the main() routine and ColaApplication"""
-# pylint: disable=unused-import
 from functools import partial
 import argparse
 import os
+import random
 import signal
 import sys
 import time
@@ -70,6 +70,7 @@ from . import version
 def setup_environment():
     """Set environment variables to control git's behavior"""
     # Allow Ctrl-C to exit
+    random.seed(hash(time.time()))
     signal.signal(signal.SIGINT, signal.SIG_DFL)
 
     # Session management wants an absolute path when restarting
@@ -584,8 +585,13 @@ class NullArgs:
 
     def __init__(self):
         self.icon_themes = []
-        self.theme = None
+        self.perf = False
+        self.prompt = False
+        self.repo = core.getcwd()
+        self.session = None
         self.settings = None
+        self.theme = None
+        self.version = False
 
 
 def null_args():
