@@ -1,5 +1,4 @@
 """Editor commands"""
-# pylint: disable=too-many-lines
 import os
 import re
 import sys
@@ -870,7 +869,7 @@ class Ignore(ContextCommand):
         new_additions = '\n'.join(self.filenames) + '\n'
         for_status = new_additions
         if self.local:
-            filename = os.path.join('.git', 'info', 'exclude')
+            filename = self.git.git_path('info', 'exclude')
         else:
             filename = '.gitignore'
         if core.exists(filename):
@@ -1657,10 +1656,9 @@ class LoadCommitMessageFromFile(ContextCommand):
     def do(self):
         path = os.path.expanduser(self.path)
         if not path or not core.isfile(path):
-            raise UsageError(
-                N_('Error: Cannot find commit template'),
-                N_('%s: No such file or directory.') % path,
-            )
+            Interaction.log(N_('Error: Cannot find commit template'))
+            Interaction.log(N_('%s: No such file or directory.') % path)
+            return
         self.model.set_directory(os.path.dirname(path))
         self.model.set_commitmsg(core.read(path))
 
@@ -1679,14 +1677,15 @@ class LoadCommitMessageFromTemplate(LoadCommitMessageFromFile):
 
     def do(self):
         if self.path is None:
-            raise UsageError(
-                N_('Error: Unconfigured commit template'),
+            Interaction.log(N_('Error: Unconfigured commit template'))
+            Interaction.log(
                 N_(
                     'A commit template has not been configured.\n'
                     'Use "git config" to define "commit.template"\n'
                     'so that it points to a commit template.'
-                ),
+                )
             )
+            return
         return LoadCommitMessageFromFile.do(self)
 
 
@@ -1986,7 +1985,6 @@ class SequenceEditorEnvironment:
         self.env = {
             'GIT_EDITOR': prefs.editor(context),
             'GIT_SEQUENCE_EDITOR': sequence_editor(),
-            'GIT_COLA_SEQ_EDITOR_CANCEL_ACTION': 'save',
         }
         self.env.update(kwargs)
 
@@ -2175,6 +2173,7 @@ class Refresh(ContextCommand):
         self.model.update_status(update_index=True)
         self.cfg.update()
         self.fsmonitor.refresh()
+        self.selection.selection_changed.emit()
 
 
 class RefreshConfig(ContextCommand):
@@ -3117,7 +3116,7 @@ def do(cls, *args, **opts):
     try:
         cmd = cls(*args, **opts)
         return cmd.do()
-    except Exception as e:  # pylint: disable=broad-except
+    except Exception as e:
         msg, details = utils.format_exception(e)
         if hasattr(cls, '__name__'):
             msg = f'{cls.__name__} exception:\n{msg}'
