@@ -292,9 +292,11 @@ class GitConfig(QtCore.QObject):
     def set_repo(self, key, value):
         if value in (None, ''):
             self.git.config(key, unset=True, _readonly=True)
+            self._local.pop(key, None)
         else:
             self.git.config(key, python_to_git(value), _readonly=True)
-        self.update()
+            self._local[key] = value
+        self.updated.emit()
         self.repo_config_changed.emit(key, value)
 
     def find(self, pat):
@@ -440,10 +442,8 @@ class GitConfig(QtCore.QObject):
         value = self.get('cola.color.%s' % key, default=default)
         struct_layout = core.encode('BBB')
         try:
-            # pylint: disable=no-member
             red, green, blue = struct.unpack(struct_layout, unhex(value))
         except (struct.error, TypeError):
-            # pylint: disable=no-member
             red, green, blue = struct.unpack(struct_layout, unhex(default))
         return (red, green, blue)
 
@@ -485,7 +485,6 @@ def _read_config_with_scope(context, cache_paths, renamed_keys):
     for line in config_output.splitlines():
         if not line:
             continue
-        # pylint: disable=too-many-boolean-expressions
         if (
             line.startswith(system_key)
             or line.startswith(global_key)
