@@ -117,7 +117,6 @@ class BranchesWidget(QtWidgets.QFrame):
         self.sort_order_button.setIcon(icon)
 
 
-# pylint: disable=too-many-ancestors
 class BranchesTreeWidget(standard.TreeWidget):
     """A tree widget for displaying branches"""
 
@@ -147,7 +146,6 @@ class BranchesTreeWidget(standard.TreeWidget):
         context.model.updated.connect(self.updated)
 
         # Expand items when they are clicked
-        # pylint: disable=no-member
         self.clicked.connect(self._toggle_expanded)
 
         # Checkout branch when double clicked
@@ -457,7 +455,7 @@ class BranchesTreeWidget(standard.TreeWidget):
         branch = self.selected_refname()
         remote_branch = gitcmds.tracked_branch(context, branch)
         context.settings.load()
-        push_settings = context.settings.get_gui_state_by_name('push')
+        push_settings = context.settings.get('push')
         remote_messages = push_settings.get('remote_messages', False)
         if remote_branch:
             remote, branch_name = gitcmds.parse_remote_branch(remote_branch)
@@ -488,7 +486,7 @@ class BranchesTreeWidget(standard.TreeWidget):
             return
         remote_branch = gitcmds.tracked_branch(context, branch)
         context.settings.load()
-        pull_settings = context.settings.get_gui_state_by_name('pull')
+        pull_settings = context.settings.get('pull')
         remote_messages = pull_settings.get('remote_messages', False)
         if remote_branch:
             remote, branch_name = gitcmds.parse_remote_branch(remote_branch)
@@ -843,7 +841,6 @@ class BranchesFilterWidget(QtWidgets.QWidget):
         self.main_layout = qtutils.hbox(defs.no_margin, defs.spacing, self.text)
         self.setLayout(self.main_layout)
 
-        # pylint: disable=no-member
         self.text.textChanged.connect(self.apply_filter)
         self.tree.updated.connect(self.apply_filter, type=Qt.QueuedConnection)
 
