@@ -13,6 +13,7 @@ from ..compat import maxsize
 from ..i18n import N_
 from ..models import dag
 from ..models import main
+from ..models import prefs
 from ..qtutils import get
 from .. import core
 from .. import cmds
@@ -122,6 +123,16 @@ class ViewerMixin:
             result = None
         return result
 
+    def with_oid_short(self, func):
+        """Run an operation with a short commit object ID"""
+        oid = self.clicked_oid()
+        if oid:
+            abbrev = prefs.abbrev(self.context)
+            result = func(oid[:abbrev])
+        else:
+            result = None
+        return result
+
     def with_selected_oid(self, func):
         """Run an operation with a commit object ID"""
         oid = self.selected_oid()
@@ -157,6 +168,10 @@ class ViewerMixin:
         """Copy the current commit object ID to the clipboard"""
         self.with_oid(qtutils.set_clipboard)
 
+    def copy_to_clipboard_short(self):
+        """Copy the current commit object ID to the clipboard"""
+        self.with_oid_short(qtutils.set_clipboard)
+
     def checkout_branch(self):
         """Checkout the clicked/selected branch"""
         branches = []
@@ -249,6 +264,11 @@ class ViewerMixin:
         context = self.context
         self.with_oid(lambda oid: browse.BrowseBranch.browse(context, oid))
 
+    def save_blob_from_parent_dialog(self):
+        """Save a file blob from the parent of the selected commit"""
+        context = self.context
+        self.with_oid(lambda oid: browse.BrowseBranch.browse(context, oid + '^'))
+
     def update_menu_actions(self, event):
         """Update menu actions to reflect the selection state"""
         selected_items = self.selected_items()
@@ -290,6 +310,7 @@ class ViewerMixin:
         )
         self.menu_actions['cherry_pick'].setEnabled(has_single_selection_or_clicked)
         self.menu_actions['copy'].setEnabled(has_single_selection_or_clicked)
+        self.menu_actions['copy_short'].setEnabled(has_single_selection_or_clicked)
         self.menu_actions['create_branch'].setEnabled(has_single_selection_or_clicked)
         self.menu_actions['create_patch'].setEnabled(has_selection)
         self.menu_actions['create_tag'].setEnabled(has_single_selection_or_clicked)
@@ -307,6 +328,9 @@ class ViewerMixin:
         )
         self.menu_actions['revert'].setEnabled(has_single_selection_or_clicked)
         self.menu_actions['save_blob'].setEnabled(has_single_selection_or_clicked)
+        self.menu_actions['save_blob_from_parent'].setEnabled(
+            has_single_selection_or_clicked
+        )
 
     def context_menu_event(self, event):
         """Build a context menu and execute it"""
@@ -338,6 +362,8 @@ class ViewerMixin:
         menu.addAction(self.menu_actions['checkout_detached'])
         menu.addSeparator()
         menu.addAction(self.menu_actions['save_blob'])
+        menu.addAction(self.menu_actions['save_blob_from_parent'])
+        menu.addAction(self.menu_actions['copy_short'])
         menu.addAction(self.menu_actions['copy'])
         menu.exec_(self.mapToGlobal(event.pos()))
 
@@ -348,50 +374,50 @@ def set_icon(icon, action):
     return action
 
 
-def viewer_actions(widget):
+def viewer_actions(widget, proxy):
     """Return common actions across the tree and graph widgets"""
     return {
         'diff_this_selected': set_icon(
             icons.compare(),
             qtutils.add_action(
-                widget, N_('Diff this -> selected'), widget.proxy.diff_this_selected
+                widget, N_('Diff this -> selected'), proxy.diff_this_selected
             ),
         ),
         'diff_selected_this': set_icon(
             icons.compare(),
             qtutils.add_action(
-                widget, N_('Diff selected -> this'), widget.proxy.diff_selected_this
+                widget, N_('Diff selected -> this'), proxy.diff_selected_this
             ),
         ),
         'create_branch': set_icon(
             icons.branch(),
-            qtutils.add_action(widget, N_('Create Branch'), widget.proxy.create_branch),
+            qtutils.add_action(widget, N_('Create Branch'), proxy.create_branch),
         ),
         'create_patch': set_icon(
             icons.save(),
-            qtutils.add_action(widget, N_('Create Patch'), widget.proxy.create_patch),
+            qtutils.add_action(widget, N_('Create Patch'), proxy.create_patch),
         ),
         'create_tag': set_icon(
             icons.tag(),
-            qtutils.add_action(widget, N_('Create Tag'), widget.proxy.create_tag),
+            qtutils.add_action(widget, N_('Create Tag'), proxy.create_tag),
         ),
         'create_tarball': set_icon(
             icons.file_zip(),
             qtutils.add_action(
-                widget, N_('Save As Tarball/Zip...'), widget.proxy.create_tarball
+                widget, N_('Save As Tarball/Zip...'), proxy.create_tarball
             ),
         ),
         'cherry_pick': set_icon(
             icons.cherry_pick(),
-            qtutils.add_action(widget, N_('Cherry Pick'), widget.proxy.cherry_pick),
+            qtutils.add_action(widget, N_('Cherry Pick'), proxy.cherry_pick),
         ),
         'revert': set_icon(
-            icons.undo(), qtutils.add_action(widget, N_('Revert'), widget.proxy.revert)
+            icons.undo(), qtutils.add_action(widget, N_('Revert'), proxy.revert)
         ),
         'diff_commit': set_icon(
             icons.diff(),
             qtutils.add_action(
-                widget, N_('Launch Diff Tool'), widget.proxy.show_diff, hotkeys.DIFF
+                widget, N_('Launch Diff Tool'), proxy.show_diff, hotkeys.DIFF
             ),
         ),
         'diff_commit_all': set_icon(
@@ -399,35 +425,31 @@ def viewer_actions(widget):
             qtutils.add_action(
                 widget,
                 N_('Launch Directory Diff Tool'),
-                widget.proxy.show_dir_diff,
+                proxy.show_dir_diff,
                 hotkeys.DIFF_SECONDARY,
             ),
         ),
         'checkout_branch': set_icon(
             icons.branch(),
-            qtutils.add_action(
-                widget, N_('Checkout Branch'), widget.proxy.checkout_branch
-            ),
+            qtutils.add_action(widget, N_('Checkout Branch'), proxy.checkout_branch),
         ),
         'checkout_detached': qtutils.add_action(
-            widget, N_('Checkout Detached HEAD'), widget.proxy.checkout_detached
+            widget, N_('Checkout Detached HEAD'), proxy.checkout_detached
         ),
         'rebase_to_commit': set_icon(
             icons.play(),
             qtutils.add_action(
-                widget, N_('Rebase to this commit'), widget.proxy.rebase_to_commit
+                widget, N_('Rebase to this commit'), proxy.rebase_to_commit
             ),
         ),
         'reset_soft': set_icon(
             icons.style_dialog_reset(),
-            qtutils.add_action(
-                widget, N_('Reset Branch (Soft)'), widget.proxy.reset_soft
-            ),
+            qtutils.add_action(widget, N_('Reset Branch (Soft)'), proxy.reset_soft),
         ),
         'reset_mixed': set_icon(
             icons.style_dialog_reset(),
             qtutils.add_action(
-                widget, N_('Reset Branch and Stage (Mixed)'), widget.proxy.reset_mixed
+                widget, N_('Reset Branch and Stage (Mixed)'), proxy.reset_mixed
             ),
         ),
         'reset_keep': set_icon(
@@ -435,7 +457,7 @@ def viewer_actions(widget):
             qtutils.add_action(
                 widget,
                 N_('Restore Worktree and Reset All (Keep Unstaged Edits)'),
-                widget.proxy.reset_keep,
+                proxy.reset_keep,
             ),
         ),
         'reset_merge': set_icon(
@@ -443,7 +465,7 @@ def viewer_actions(widget):
             qtutils.add_action(
                 widget,
                 N_('Restore Worktree and Reset All (Merge)'),
-                widget.proxy.reset_merge,
+                proxy.reset_merge,
             ),
         ),
         'reset_hard': set_icon(
@@ -451,28 +473,41 @@ def viewer_actions(widget):
             qtutils.add_action(
                 widget,
                 N_('Restore Worktree and Reset All (Hard)'),
-                widget.proxy.reset_hard,
+                proxy.reset_hard,
             ),
         ),
         'restore_worktree': set_icon(
             icons.edit(),
-            qtutils.add_action(
-                widget, N_('Restore Worktree'), widget.proxy.restore_worktree
-            ),
+            qtutils.add_action(widget, N_('Restore Worktree'), proxy.restore_worktree),
         ),
         'save_blob': set_icon(
+            icons.save(),
+            qtutils.add_action(widget, N_('Grab File...'), proxy.save_blob_dialog),
+        ),
+        'save_blob_from_parent': set_icon(
             icons.save(),
             qtutils.add_action(
-                widget, N_('Grab File...'), widget.proxy.save_blob_dialog
+                widget,
+                N_('Grab File from Parent Commit...'),
+                proxy.save_blob_from_parent_dialog,
             ),
         ),
         'copy': set_icon(
             icons.copy(),
             qtutils.add_action(
                 widget,
-                N_('Copy SHA-1'),
-                widget.proxy.copy_to_clipboard,
-                hotkeys.COPY_SHA1,
+                N_('Copy Commit'),
+                proxy.copy_to_clipboard,
+                hotkeys.COPY_COMMIT_ID,
+            ),
+        ),
+        'copy_short': set_icon(
+            icons.copy(),
+            qtutils.add_action(
+                widget,
+                N_('Copy Commit (Short)'),
+                proxy.copy_to_clipboard_short,
+                hotkeys.COPY,
             ),
         ),
     }
@@ -556,7 +591,6 @@ class CommitTreeWidgetItem(QtWidgets.QTreeWidgetItem):
         self.setText(2, commit.authdate)
 
 
-# pylint: disable=too-many-ancestors
 class CommitTreeWidget(standard.TreeWidget, ViewerMixin):
     """Display commits using a flat treewidget in "list" mode"""
 
@@ -577,7 +611,6 @@ class CommitTreeWidget(standard.TreeWidget, ViewerMixin):
         self.selecting = False
         self.commits = []
         self._adjust_columns = False
-
         self.action_up = qtutils.add_action(
             self, N_('Go Up'), self.go_up, hotkeys.MOVE_UP
         )
@@ -590,7 +623,6 @@ class CommitTreeWidget(standard.TreeWidget, ViewerMixin):
             self, N_('Zoom to Fit'), self.zoom_to_fit.emit, hotkeys.FIT
         )
 
-        # pylint: disable=no-member
         self.itemSelectionChanged.connect(self.selection_changed)
 
     def export_state(self):
@@ -802,9 +834,8 @@ class GitDAG(standard.MainWindow):
             self.treewidget, self.graphview, self.filewidget
         )
 
-        self.viewer_actions = actions = viewer_actions(self)
-        self.treewidget.menu_actions = actions
-        self.graphview.menu_actions = actions
+        self.treewidget.menu_actions = viewer_actions(self.treewidget, self.proxy)
+        self.graphview.menu_actions = viewer_actions(self.graphview, self.proxy)
 
         self.controls_layout = qtutils.hbox(
             defs.no_margin, defs.spacing, self.revtext, self.maxresults
@@ -890,15 +921,12 @@ class GitDAG(standard.MainWindow):
         self.treewidget.diff_commits.connect(self.diff_commits)
         self.graphview.diff_commits.connect(self.diff_commits)
         self.filewidget.grab_file.connect(self.grab_file)
-
-        # pylint: disable=no-member
+        self.filewidget.grab_file_from_parent.connect(self.grab_file_from_parent)
         self.maxresults.editingFinished.connect(self.display)
-
         self.revtext.textChanged.connect(self.text_changed)
         self.revtext.activated.connect(self.display)
         self.revtext.enter.connect(self.display)
         self.revtext.down.connect(self.focus_tree)
-
         # The model is updated in another thread so use
         # signals/slots to bring control back to the main GUI thread
         self.model.updated.connect(self.model_updated, type=Qt.QueuedConnection)
@@ -1117,6 +1145,12 @@ class GitDAG(standard.MainWindow):
         model = browse.BrowseModel(oid, filename=filename)
         browse.save_path(self.context, filename, model)
 
+    def grab_file_from_parent(self, filename):
+        """Save the selected file from parent commit in the file list widget"""
+        oid = self.treewidget.selected_oid() + '^'
+        model = browse.BrowseModel(oid, filename=filename)
+        browse.save_path(self.context, filename, model)
+
 
 class ReaderThread(QtCore.QThread):
     begin = Signal()
@@ -1580,7 +1614,6 @@ class Label(QtWidgets.QGraphicsItem):
             current_width += text_rect.width() + spacing
 
 
-# pylint: disable=too-many-ancestors
 class GraphView(QtWidgets.QGraphicsView, ViewerMixin):
     commits_selected = Signal(object)
     diff_commits = Signal(object, object)
@@ -1626,10 +1659,8 @@ class GraphView(QtWidgets.QGraphicsView, ViewerMixin):
 
         scene = QtWidgets.QGraphicsScene(self)
         scene.setItemIndexMethod(QtWidgets.QGraphicsScene.BspTreeIndex)
-        self.setScene(scene)
-
-        # pylint: disable=no-member
         scene.selectionChanged.connect(self.selection_changed)
+        self.setScene(scene)
 
         self.setRenderHint(QtGui.QPainter.Antialiasing)
         self.setViewportUpdateMode(self.SmartViewportUpdate)
@@ -2367,5 +2398,5 @@ def sort_by_generation(commits):
 
 # Glossary
 # ========
-# oid -- Git objects IDs (i.e. SHA-1 IDs)
+# oid -- Git objects IDs (i.e. SHA-1 / SHA-256 IDs)
 # ref -- Git references that resolve to a commit-ish (HEAD, branches, tags)
