@@ -1,6 +1,7 @@
 from qtpy import QtWidgets
 from qtpy.QtCore import Signal
 from qtpy.QtCore import QSize
+from qtpy.QtCore import Qt
 
 from .. import cmds
 from .. import hotkeys
@@ -9,14 +10,15 @@ from ..i18n import N_
 from .standard import TreeWidget
 
 
-# pylint: disable=too-many-ancestors
 class FileWidget(TreeWidget):
     files_selected = Signal(object)
     difftool_selected = Signal(object)
     histories_selected = Signal(object)
     grab_file = Signal(object)
+    grab_file_from_parent = Signal(object)
+    remark_toggled = Signal(object, object)
 
-    def __init__(self, context, parent):
+    def __init__(self, context, parent, remarks=False):
         TreeWidget.__init__(self, parent)
         self.context = context
 
@@ -26,20 +28,32 @@ class FileWidget(TreeWidget):
         self.show_history_action = qtutils.add_action(
             self, N_('Show History'), self.show_history, hotkeys.HISTORY
         )
-
         self.launch_difftool_action = qtutils.add_action(
             self, N_('Launch Diff Tool'), self.show_diff
         )
-
         self.launch_editor_action = qtutils.add_action(
             self, N_('Launch Editor'), self.edit_paths, hotkeys.EDIT
         )
-
         self.grab_file_action = qtutils.add_action(
             self, N_('Grab File...'), self._grab_file
         )
+        self.grab_file_from_parent_action = qtutils.add_action(
+            self, N_('Grab File from Parent Commit...'), self._grab_file_from_parent
+        )
+
+        if remarks:
+            self.toggle_remark_actions = tuple(
+                qtutils.add_action(
+                    self,
+                    r,
+                    lambda remark=r: self.toggle_remark(remark),
+                    hotkeys.hotkey(Qt.CTRL | getattr(Qt, 'Key_' + r)),
+                )
+                for r in map(str, range(10))
+            )
+        else:
+            self.toggle_remark_actions = tuple()
 
-        # pylint: disable=no-member
         self.itemSelectionChanged.connect(self.selection_changed)
 
     def selection_changed(self):
@@ -106,9 +120,13 @@ class FileWidget(TreeWidget):
     def contextMenuEvent(self, event):
         menu = qtutils.create_menu(N_('Actions'), self)
         menu.addAction(self.grab_file_action)
+        menu.addAction(self.grab_file_from_parent_action)
         menu.addAction(self.show_history_action)
         menu.addAction(self.launch_difftool_action)
         menu.addAction(self.launch_editor_action)
+        if self.toggle_remark_actions:
+            menu_toggle_remark = menu.addMenu(N_('Toggle remark of touching commits'))
+            tuple(map(menu_toggle_remark.addAction, self.toggle_remark_actions))
         menu.exec_(self.mapToGlobal(event.pos()))
 
     def show_diff(self):
@@ -118,6 +136,10 @@ class FileWidget(TreeWidget):
         for path in self.selected_paths():
             self.grab_file.emit(path)
 
+    def _grab_file_from_parent(self):
+        for path in self.selected_paths():
+            self.grab_file_from_parent.emit(path)
+
     def selected_paths(self):
         return [i.path for i in self.selected_items()]
 
@@ -129,6 +151,11 @@ class FileWidget(TreeWidget):
         paths = [i.path for i in items]
         self.histories_selected.emit(paths)
 
+    def toggle_remark(self, remark):
+        items = self.selected_items()
+        paths = tuple(i.path for i in items)
+        self.remark_toggled.emit(remark, paths)
+
 
 class FileTreeWidgetItem(QtWidgets.QTreeWidgetItem):
     def __init__(self, file_log, parent=None):
