@@ -61,7 +61,6 @@ class MainView(standard.MainWindow):
     config_actions_changed = Signal(object)
 
     def __init__(self, context, parent=None):
-        # pylint: disable=too-many-statements,too-many-locals
         standard.MainWindow.__init__(self, parent)
         self.setAttribute(Qt.WA_DeleteOnClose)
 
@@ -196,9 +195,14 @@ class MainView(standard.MainWindow):
             False,
         )
         self.commit_amend_action.setIcon(icons.edit())
-        self.commit_amend_action.setShortcut(hotkeys.AMEND)
+        self.commit_amend_action.setShortcuts(hotkeys.AMEND)
         self.commit_amend_action.setShortcutContext(Qt.WidgetShortcut)
 
+        # Make Cmd-M minimize the window on macOS.
+        if utils.is_darwin():
+            self.minimize_action = add_action(
+                self, N_('Minimize Window'), self.showMinimized, hotkeys.MACOS_MINIMIZE
+            )
         self.unstage_all_action = add_action(
             self, N_('Unstage All'), cmds.run(cmds.UnstageAll, context)
         )
@@ -857,7 +861,6 @@ class MainView(standard.MainWindow):
 
         # View Menu
         self.view_menu = add_menu(N_('View'), self.menubar)
-        # pylint: disable=no-member
         self.view_menu.aboutToShow.connect(lambda: self.build_view_menu(self.view_menu))
         self.setup_dockwidget_view_menu()
         if utils.is_darwin():
@@ -983,6 +986,8 @@ class MainView(standard.MainWindow):
 
     def build_view_menu(self, menu):
         menu.clear()
+        if utils.is_darwin():
+            menu.addAction(self.minimize_action)
         menu.addAction(self.browse_action)
         menu.addAction(self.dag_action)
         menu.addSeparator()
