@@ -1,5 +1,12 @@
 """Widgets for Fetch, Push, and Pull"""
 import fnmatch
+import time
+import os
+
+try:
+    import notifypy
+except (ImportError, ModuleNotFoundError):
+    notifypy = None
 
 from qtpy import QtGui
 from qtpy import QtWidgets
@@ -7,10 +14,16 @@ from qtpy.QtCore import Qt
 
 from ..i18n import N_
 from ..interaction import Interaction
+from ..models import main
+from ..models import prefs
+from ..models.main import FETCH, FETCH_HEAD, PULL, PUSH
 from ..qtutils import connect_button
 from ..qtutils import get
+from .. import core
+from .. import git
 from .. import gitcmds
 from .. import icons
+from .. import resources
 from .. import qtutils
 from .. import utils
 from . import defs
@@ -18,11 +31,6 @@ from . import log
 from . import standard
 
 
-FETCH = 'FETCH'
-PUSH = 'PUSH'
-PULL = 'PULL'
-
-
 def fetch(context):
     """Fetch from remote repositories"""
     return run(context, Fetch)
@@ -115,6 +123,41 @@ class ActionTask(qtutils.Task):
         return self.model_action(self.remote, **self.kwargs)
 
 
+def _emit_push_notification(selected_remotes, pushed_remotes, unpushed_remotes):
+    """Emit desktop notification when pushing remotes"""
+    if notifypy is None:
+        return
+
+    notification = notifypy.Notify()
+
+    total = len(selected_remotes)
+    count = len(pushed_remotes)
+    scope = {
+        'total': total,
+        'count': count,
+    }
+    notification.title = N_('Pushed %(count)s / %(total)s remotes - Git Cola') % scope
+
+    pushed_message = N_('Pushed: %s') % ', '.join(pushed_remotes)
+    unpushed_message = N_('Not pushed: %s') % ', '.join(unpushed_remotes)
+    success_icon = resources.icon_path('git-cola-ok.svg')
+    error_icon = resources.icon_path('git-cola-error.svg')
+
+    if unpushed_remotes:
+        notification.icon = error_icon
+    else:
+        notification.icon = success_icon
+
+    if pushed_remotes and unpushed_remotes:
+        notification.message = unpushed_message + '\t\t' + pushed_message
+    elif pushed_remotes:
+        notification.message = pushed_message
+    else:
+        notification.message = unpushed_message
+
+    notification.send()
+
+
 class RemoteActionDialog(standard.Dialog):
     """Interface for performing remote operations"""
 
@@ -130,25 +173,29 @@ class RemoteActionDialog(standard.Dialog):
         self.action = action
         self.filtered_remote_branches = []
         self.selected_remotes = []
+        self.selected_remotes_by_worktree = {}
+        self.last_updated = 0.0
 
         self.runtask = qtutils.RunTask(parent=self)
         self.local_label = QtWidgets.QLabel()
         self.local_label.setText(N_('Local Branch'))
 
         self.local_branch = QtWidgets.QLineEdit()
-        qtutils.add_completer(self.local_branch, model.local_branches)
+        self.local_branch.textChanged.connect(self.local_branch_text_changed)
+        local_branches = self.get_local_branches()
+        qtutils.add_completer(self.local_branch, local_branches)
 
         self.local_branches = QtWidgets.QListWidget()
-        self.local_branches.addItems(model.local_branches)
+        self.local_branches.addItems(local_branches)
 
         self.remote_label = QtWidgets.QLabel()
         self.remote_label.setText(N_('Remote'))
 
         self.remote_name = QtWidgets.QLineEdit()
         qtutils.add_completer(self.remote_name, model.remotes)
-        # pylint: disable=no-member
+
         self.remote_name.editingFinished.connect(self.remote_name_edited)
-        self.remote_name.textEdited.connect(lambda x: self.remote_name_edited())
+        self.remote_name.textEdited.connect(lambda _: self.remote_name_edited())
 
         self.remotes = QtWidgets.QListWidget()
         if action == PUSH:
@@ -160,6 +207,7 @@ class RemoteActionDialog(standard.Dialog):
         self.remote_branch_label.setText(N_('Remote Branch'))
 
         self.remote_branch = QtWidgets.QLineEdit()
+        self.remote_branch.textChanged.connect(lambda _: self.update_command_display())
         remote_branches = strip_remotes(model.remote_branches)
         qtutils.add_completer(self.remote_branch, remote_branches)
 
@@ -186,6 +234,7 @@ class RemoteActionDialog(standard.Dialog):
         self.ff_only_checkbox = qtutils.checkbox(
             checked=True, text=text, tooltip=tooltip
         )
+        self.ff_only_checkbox.toggled.connect(self.update_command_display)
 
         text = N_('No fast-forward')
         tooltip = N_(
@@ -194,6 +243,7 @@ class RemoteActionDialog(standard.Dialog):
         self.no_ff_checkbox = qtutils.checkbox(
             checked=False, text=text, tooltip=tooltip
         )
+        self.no_ff_checkbox.toggled.connect(self.update_command_display)
         text = N_('Force')
         tooltip = N_(
             'Allow non-fast-forward updates.  Using "force" can '
@@ -203,20 +253,25 @@ class RemoteActionDialog(standard.Dialog):
         self.force_checkbox = qtutils.checkbox(
             checked=False, text=text, tooltip=tooltip
         )
+        self.force_checkbox.toggled.connect(self.update_command_display)
 
         self.tags_checkbox = qtutils.checkbox(text=N_('Include tags '))
+        self.tags_checkbox.toggled.connect(self.update_command_display)
 
         tooltip = N_(
             'Remove remote-tracking branches that no longer exist on the remote'
         )
         self.prune_checkbox = qtutils.checkbox(text=N_('Prune '), tooltip=tooltip)
+        self.prune_checkbox.toggled.connect(self.update_command_display)
 
         tooltip = N_('Rebase the current branch instead of merging')
         self.rebase_checkbox = qtutils.checkbox(text=N_('Rebase'), tooltip=tooltip)
+        self.rebase_checkbox.toggled.connect(self.update_command_display)
 
         text = N_('Set upstream')
         tooltip = N_('Configure the remote branch as the the new upstream')
         self.upstream_checkbox = qtutils.checkbox(text=text, tooltip=tooltip)
+        self.upstream_checkbox.toggled.connect(self.update_command_display)
 
         text = N_('Close on completion')
         tooltip = N_('Close dialog when completed')
@@ -249,6 +304,8 @@ class RemoteActionDialog(standard.Dialog):
             disable=(self.buttons_group, self.inputs_group),
         )
 
+        self.command_display = log.LogWidget(self.context, display_usage=False)
+
         self.local_branch_layout = qtutils.hbox(
             defs.small_margin, defs.spacing, self.local_label, self.local_branch
         )
@@ -313,8 +370,13 @@ class RemoteActionDialog(standard.Dialog):
         self.top_layout = qtutils.hbox(defs.no_margin, defs.spacing, *widgets)
 
         self.main_layout = qtutils.vbox(
-            defs.margin, defs.spacing, self.top_layout, self.options_layout
+            defs.margin,
+            defs.spacing,
+            self.top_layout,
+            self.command_display,
+            self.options_layout,
         )
+        self.main_layout.setStretchFactor(self.top_layout, 2)
         self.setLayout(self.main_layout)
 
         default_remote = get_default_remote(context)
@@ -329,11 +391,9 @@ class RemoteActionDialog(standard.Dialog):
                 self.set_remote_name(remotes[0])
 
         # Trim the remote list to just the default remote
-        self.update_remotes()
-        self.set_field_defaults()
+        self.update_remotes(update_command_display=False)
 
         # Setup signals and slots
-        # pylint: disable=no-member
         self.remotes.itemSelectionChanged.connect(self.update_remotes)
 
         local = self.local_branches
@@ -382,6 +442,7 @@ class RemoteActionDialog(standard.Dialog):
             self.ff_only_checkbox.hide()
 
         self.init_size(parent=parent)
+        self.set_field_defaults()
 
     def set_rebase(self, value):
         """Check the rebase checkbox"""
@@ -391,11 +452,11 @@ class RemoteActionDialog(standard.Dialog):
         """Set sensible initial defaults"""
         # Default to "git fetch origin main"
         action = self.action
-        if action in (FETCH, PULL):
-            self.local_branch.setText('')
-            self.remote_branch.setText('')
-            return
-
+        if action == FETCH:
+            self.set_local_branch('')
+            self.set_remote_branch('')
+        if action == PULL:  # Nothing to do when fetching.
+            pass
         # Select the current branch by default for push
         if action == PUSH:
             branch = self.model.currentbranch
@@ -403,9 +464,29 @@ class RemoteActionDialog(standard.Dialog):
                 idx = self.model.local_branches.index(branch)
             except ValueError:
                 return
-            if self.select_local_branch(idx):
-                self.set_local_branch(branch)
-            self.set_remote_branch('')
+            self.select_local_branch(idx)
+            self.set_remote_branch(branch)
+
+        self.update_command_display()
+
+    def update_command_display(self):
+        """Display the git commands that will be run"""
+        commands = ['']
+        for remote in self.selected_remotes:
+            cmd = ['git', self.action]
+            _, kwargs = self.common_args()
+            args, kwargs = main.remote_args(self.context, remote, self.action, **kwargs)
+            cmd.extend(git.transform_kwargs(**kwargs))
+            cmd.extend(args)
+            commands.append(core.list2cmdline(cmd))
+        self.command_display.set_output('\n'.join(commands))
+
+    def local_branch_text_changed(self, value):
+        """Update the remote branch field in response to local branch text edits"""
+        if self.action == PUSH:
+            self.remote_branches.clearSelection()
+            self.set_remote_branch(value)
+        self.update_command_display()
 
     def set_remote_name(self, remote_name):
         """Set the remote name"""
@@ -434,24 +515,25 @@ class RemoteActionDialog(standard.Dialog):
         """Select the first remote in the list view"""
         return self.select_remote(0)
 
-    def select_remote(self, idx):
+    def select_remote(self, idx, make_current=True):
         """Select a remote by index"""
         item = self.remotes.item(idx)
         if item:
             item.setSelected(True)
-            self.remotes.setCurrentItem(item)
-            self.set_remote_name(item.text())
+            if make_current:
+                self.remotes.setCurrentItem(item)
+                self.set_remote_name(item.text())
             result = True
         else:
             result = False
         return result
 
-    def select_remote_by_name(self, remote):
+    def select_remote_by_name(self, remote, make_current=True):
         """Select a remote by name"""
         remotes = self.model.remotes
         if remote in remotes:
             idx = remotes.index(remote)
-            result = self.select_remote(idx)
+            result = self.select_remote(idx, make_current=make_current)
         else:
             result = False
         return result
@@ -482,7 +564,21 @@ class RemoteActionDialog(standard.Dialog):
         if item:
             item.setSelected(True)
             self.local_branches.setCurrentItem(item)
-            self.local_branch.setText(item.text())
+            self.set_local_branch(item.text())
+            result = True
+        else:
+            result = False
+        return result
+
+    def select_remote_branch(self, idx):
+        """Selects a remote branch by index in the list view"""
+        item = self.remote_branches.item(idx)
+        if item:
+            item.setSelected(True)
+            self.remote_branches.setCurrentItem(item)
+            remote_branch = item.text()
+            branch = remote_branch.split('/', 1)[-1]
+            self.set_remote_branch(branch)
             result = True
         else:
             result = False
@@ -497,7 +593,7 @@ class RemoteActionDialog(standard.Dialog):
             displayed.append(display)
         qtutils.set_items(widget, displayed)
 
-    def update_remotes(self):
+    def update_remotes(self, update_command_display=True):
         """Update the remote name when a remote from the list is selected"""
         widget = self.remotes
         remotes = self.model.remotes
@@ -508,13 +604,19 @@ class RemoteActionDialog(standard.Dialog):
         self.set_remote_name(selection)
         self.selected_remotes = qtutils.selected_items(self.remotes, self.model.remotes)
         self.set_remote_to(selection, self.selected_remotes)
+        worktree = self.context.git.worktree()
+        self.selected_remotes_by_worktree[worktree] = self.selected_remotes
+        if update_command_display:
+            self.update_command_display()
 
     def set_remote_to(self, _remote, selected_remotes):
         context = self.context
         all_branches = gitcmds.branch_list(context, remote=True)
         branches = []
         patterns = []
+        remote = ''
         for remote_name in selected_remotes:
+            remote = remote or remote_name  # Use the first remote when prepopulating.
             patterns.append(remote_name + '/*')
 
         for branch in all_branches:
@@ -526,22 +628,51 @@ class RemoteActionDialog(standard.Dialog):
             self.set_remote_branches(branches)
         else:
             self.set_remote_branches(all_branches)
-        self.set_remote_branch('')
+
+        if self.action == FETCH:
+            self.set_remote_branch('')
+        elif self.action in (PUSH, PULL):
+            branch = ''
+            current_branch = (
+                self.local_branch.text() or self.context.model.currentbranch
+            )
+            remote_branch = f'{remote}/{current_branch}'
+            if branches and remote_branch in branches:
+                branch = current_branch
+                try:
+                    idx = self.filtered_remote_branches.index(remote_branch)
+                except ValueError:
+                    pass
+                self.select_remote_branch(idx)
+                return
+            self.set_remote_branch(branch)
 
     def remote_name_edited(self):
         """Update the current remote when the remote name is typed manually"""
         remote = self.remote_name.text()
-        self.set_remote_to(remote, [remote])
+        self.update_selected_remotes(remote)
+        self.set_remote_to(remote, self.selected_remotes)
+        self.update_command_display()
+
+    def get_local_branches(self):
+        """Calculate the list of local branches"""
+        if self.action == FETCH:
+            branches = self.model.local_branches + [FETCH_HEAD]
+        else:
+            branches = self.model.local_branches
+        return branches
 
     def update_local_branches(self):
         """Update the local/remote branch names when a branch is selected"""
-        branches = self.model.local_branches
+        branches = self.get_local_branches()
         widget = self.local_branches
         selection = qtutils.selected_item(widget, branches)
         if not selection:
             return
         self.set_local_branch(selection)
-        self.set_remote_branch(selection)
+        if self.action == FETCH and selection != FETCH_HEAD:
+            self.set_remote_branch(selection)
+        self.update_command_display()
 
     def update_remote_branches(self):
         """Update the remote branch name when a branch is selected"""
@@ -554,6 +685,7 @@ class RemoteActionDialog(standard.Dialog):
         if branch == 'HEAD':
             return
         self.set_remote_branch(branch)
+        self.update_command_display()
 
     def common_args(self):
         """Returns git arguments common to fetch/push/pull"""
@@ -590,9 +722,23 @@ class RemoteActionDialog(standard.Dialog):
         """Push to all selected remotes"""
         selected_remotes = self.selected_remotes
         all_results = None
+
+        pushed_remotes = []
+        unpushed_remotes = []
+
         for remote in selected_remotes:
             result = self.model.push(remote, *args, **kwargs)
+
+            if result[0] == 0:
+                pushed_remotes.append(remote)
+            else:
+                unpushed_remotes.append(remote)
+
             all_results = combine(result, all_results)
+
+        if prefs.notify_on_push(self.context):
+            _emit_push_notification(selected_remotes, pushed_remotes, unpushed_remotes)
+
         return all_results
 
     def action_callback(self):
@@ -612,7 +758,7 @@ class RemoteActionDialog(standard.Dialog):
             Interaction.log(errmsg)
             return
         remote, kwargs = self.common_args()
-        self.selected_remotes = qtutils.selected_items(self.remotes, self.model.remotes)
+        self.update_selected_remotes(remote)
 
         # Check if we're about to create a new branch and warn.
         remote_branch = self.remote_branch.text()
@@ -681,13 +827,21 @@ class RemoteActionDialog(standard.Dialog):
             result=result,
         )
 
+    def update_selected_remotes(self, remote):
+        """Update the selected remotes when an ad-hoc remote is typed in"""
+        self.selected_remotes = qtutils.selected_items(self.remotes, self.model.remotes)
+        if remote not in self.selected_remotes:
+            self.selected_remotes = [remote]
+        worktree = self.context.git.worktree()
+        self.selected_remotes_by_worktree[worktree] = self.selected_remotes
+
     def action_completed(self, task):
         """Grab the results of the action and finish up"""
         if not task.result or not isinstance(task.result, (list, tuple)):
             return
 
         status, out, err = task.result
-        command = 'git %s' % self.action.lower()
+        command = 'git %s' % self.action
         message = Interaction.format_command_status(command, status)
         details = Interaction.format_out_err(out, err)
 
@@ -713,6 +867,8 @@ class RemoteActionDialog(standard.Dialog):
         state = standard.Dialog.export_state(self)
         state['close_on_completion'] = get(self.close_on_completion_checkbox)
         state['remote_messages'] = get(self.remote_messages_checkbox)
+        state['selected_remotes'] = self.selected_remotes_by_worktree
+        state['last_updated'] = self.last_updated
         return state
 
     def apply_state(self, state):
@@ -724,8 +880,40 @@ class RemoteActionDialog(standard.Dialog):
         # Restore the "show remote messages" checkbox
         remote_messages = bool(state.get('remote_messages', False))
         self.remote_messages_checkbox.setChecked(remote_messages)
+        # Restore the selected remotes.
+        self.selected_remotes_by_worktree = state.get('selected_remotes', {})
+        self.last_updated = state.get('last_updated', 0.0)
+        current_time = time.time()
+        one_month = 60.0 * 60.0 * 24.0 * 31.0  # one month is ~31 days.
+        if (current_time - self.last_updated) > one_month:
+            self._prune_selected_remotes()
+            self.last_updated = current_time
+        # Selected remotes are stored per-worktree.
+        worktree = self.context.git.worktree()
+        selected_remotes = self.selected_remotes_by_worktree.get(worktree, [])
+        if selected_remotes:
+            # Restore the stored selection. We stash away the current selection so that
+            # we can restore it in case we are unable to apply the stored selection.
+            current_selection = self.remotes.selectedItems()
+            self.remotes.clearSelection()
+            selected = False
+            for idx, remote in enumerate(selected_remotes):
+                make_current = idx == 0 or not selected
+                if self.select_remote_by_name(remote, make_current=make_current):
+                    selected = True
+            # Restore the original selection if nothing was selected.
+            if not selected:
+                for item in current_selection:
+                    item.setSelected(True)
         return result
 
+    def _prune_selected_remotes(self):
+        """Prune stale worktrees from the persistent selected_remotes_by_worktree"""
+        worktrees = list(self.selected_remotes_by_worktree.keys())
+        for worktree in worktrees:
+            if not os.path.exists(worktree):
+                self.selected_remotes_by_worktree.pop(worktree, None)
+
 
 # Use distinct classes so that each saves its own set of preferences
 class Fetch(RemoteActionDialog):
