@@ -11,7 +11,6 @@ from ..i18n import N_
 from .text import HintedTextEdit
 
 
-# pylint: disable=too-many-ancestors
 class SpellCheckTextEdit(HintedTextEdit):
     def __init__(self, context, hint, check=None, parent=None):
         HintedTextEdit.__init__(self, context, hint, parent)
@@ -24,9 +23,13 @@ class SpellCheckTextEdit(HintedTextEdit):
         if event.button() == Qt.RightButton:
             # Rewrite the mouse event to a left button event so the cursor is
             # moved to the location of the pointer.
+            if hasattr(event, 'position'):  # Qt6
+                position = event.position()
+            else:
+                position = event.pos()
             event = QtGui.QMouseEvent(
                 QtCore.QEvent.MouseButtonPress,
-                event.pos(),
+                position,
                 Qt.LeftButton,
                 Qt.LeftButton,
                 Qt.NoModifier,
@@ -220,7 +223,6 @@ class SpellAction(QtWidgets.QAction):
 
     def __init__(self, *args):
         QtWidgets.QAction.__init__(self, *args)
-        # pylint: disable=no-member
         self.triggered.connect(self.correct)
 
     def correct(self):
