@@ -62,17 +62,21 @@ class WidgetMixin:
         return self.__class__.__name__.lower()
 
     def save_state(self, settings=None):
+        """Save tool settings to the ~/.config/git-cola/settings file"""
         save = True
+        sync = True
         context = getattr(self, 'context', None)
         if context:
             cfg = context.cfg
             save = cfg.get('cola.savewindowsettings', default=True)
+            sync = cfg.get('cola.sync', default=True)
         if save:
             if settings is None:
                 settings = Settings.read()
-            settings.save_gui_state(self)
+            settings.save_gui_state(self, sync=sync)
 
     def restore_state(self, settings=None):
+        """Read and apply saved tool settings"""
         if settings is None:
             settings = Settings.read()
         state = settings.get_gui_state(self)
@@ -83,8 +87,7 @@ class WidgetMixin:
         return result
 
     def apply_state(self, state):
-        """Imports data for view save/restore"""
-
+        """Import data for view save/restore"""
         width = utils.asint(state.get('width'))
         height = utils.asint(state.get('height'))
         x = utils.asint(state.get('x'))
@@ -117,14 +120,17 @@ class WidgetMixin:
         return state
 
     def save_settings(self, settings=None):
+        """Save tool state using the specified settings backend"""
         return self.save_state(settings=settings)
 
     def closeEvent(self, event):
+        """Save settings when the top-level widget is closed"""
         self.save_settings()
         self.closed.emit(self)
         self.Base.closeEvent(self, event)
 
     def init_size(self, parent=None, settings=None, width=0, height=0):
+        """Set a tool's initial size"""
         if not width:
             width = defs.dialog_w
         if not height:
@@ -222,7 +228,6 @@ class MainWindowMixin(WidgetMixin):
             widget.titleBarWidget().update_tooltips()
 
 
-# pylint: disable=too-many-ancestors
 class ListWidget(QtWidgets.QListWidget):
     """QListWidget with vim j/k navigation hotkeys"""
 
@@ -547,7 +552,6 @@ class MainWindow(MainWindowMixin, QtWidgets.QMainWindow):
         MainWindowMixin.__init__(self)
 
 
-# pylint: disable=too-many-ancestors
 class TreeView(QtWidgets.QTreeView):
     Mixin = TreeMixin
 
@@ -581,7 +585,6 @@ class TreeView(QtWidgets.QTreeView):
         return self._mixin.set_column_widths(widths)
 
 
-# pylint: disable=too-many-ancestors
 class TreeWidget(QtWidgets.QTreeWidget):
     Mixin = TreeMixin
 
@@ -615,7 +618,6 @@ class TreeWidget(QtWidgets.QTreeWidget):
         return self._mixin.set_column_widths(widths)
 
 
-# pylint: disable=too-many-ancestors
 class DraggableTreeWidget(TreeWidget):
     Mixin = DraggableTreeMixin
     items_moved = Signal(object)
