@@ -1,5 +1,4 @@
 """Text widgets"""
-# pylint: disable=unexpected-keyword-arg
 from functools import partial
 import math
 
@@ -261,12 +260,10 @@ class BaseTextEditExtension(QtCore.QObject):
         """Called during init for class-specific settings"""
         return
 
-    # pylint: disable=unused-argument
     def set_textwidth(self, width):
         """Set the text width"""
         return
 
-    # pylint: disable=unused-argument
     def set_linebreak(self, brk):
         """Enable word wrapping"""
         return
@@ -811,7 +808,6 @@ class HintedPlainTextEdit(PlainTextEdit):
         self.setFont(qtutils.diff_font(context))
         self.set_tabwidth(prefs.tabwidth(context))
         # Refresh palettes when text changes
-        # pylint: disable=no-member
         self.textChanged.connect(self.hint.refresh)
         self.set_mouse_zoom(context.cfg.get(prefs.MOUSE_ZOOM, default=True))
 
@@ -834,7 +830,6 @@ class HintedTextEdit(TextEdit):
         self.hint = HintWidget(self, hint)
         self.hint.init()
         # Refresh palettes when text changes
-        # pylint: disable=no-member
         self.textChanged.connect(self.hint.refresh)
         self.setFont(qtutils.diff_font(context))
 
@@ -980,7 +975,6 @@ class VimMixin:
         return self.Base.keyPressEvent(widget, event)
 
 
-# pylint: disable=too-many-ancestors
 class VimHintedPlainTextEdit(HintedPlainTextEdit):
     """HintedPlainTextEdit with vim hotkeys
 
@@ -1010,7 +1004,6 @@ class VimHintedPlainTextEdit(HintedPlainTextEdit):
         return self._mixin.keyPressEvent(event)
 
 
-# pylint: disable=too-many-ancestors
 class VimTextEdit(MonoTextEdit):
     """Text viewer with vim-like hotkeys
 
@@ -1050,7 +1043,6 @@ class HintedDefaultLineEdit(LineEdit):
             self.setToolTip(tooltip)
         self.hint = HintWidget(self, hint)
         self.hint.init()
-        # pylint: disable=no-member
         self.textChanged.connect(lambda text: self.hint.refresh())
 
 
@@ -1203,7 +1195,7 @@ class LineNumbers(TextDecorator):
 class TextLabel(QtWidgets.QLabel):
     """A text label that elides its display"""
 
-    def __init__(self, parent=None, open_external_links=True):
+    def __init__(self, parent=None, open_external_links=True, selectable=True):
         QtWidgets.QLabel.__init__(self, parent)
         self._display = ''
         self._template = ''
@@ -1214,9 +1206,11 @@ class TextLabel(QtWidgets.QLabel):
             QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Minimum
         )
         self.setSizePolicy(policy)
-        self.setTextInteractionFlags(
-            Qt.TextSelectableByMouse | Qt.LinksAccessibleByMouse
-        )
+        if selectable:
+            interaction_flags = Qt.TextSelectableByMouse | Qt.LinksAccessibleByMouse
+        else:
+            interaction_flags = Qt.LinksAccessibleByMouse
+        self.setTextInteractionFlags(interaction_flags)
         self.setOpenExternalLinks(open_external_links)
 
     def elide(self):
@@ -1240,6 +1234,10 @@ class TextLabel(QtWidgets.QLabel):
         if text != self._template:
             self._display = text
 
+    def get(self):
+        """Return the label's inner text value"""
+        return self._text
+
     # Qt overrides
     def setFont(self, font):
         self._metrics = QtGui.QFontMetrics(font)
@@ -1256,14 +1254,16 @@ class TextLabel(QtWidgets.QLabel):
 class PlainTextLabel(TextLabel):
     """A plaintext label that elides its display"""
 
-    def __init__(self, parent=None):
-        super().__init__(parent=parent, open_external_links=False)
+    def __init__(self, selectable=True, parent=None):
+        super().__init__(
+            selectable=selectable, parent=parent, open_external_links=False
+        )
         self.setTextFormat(Qt.PlainText)
 
 
 class RichTextLabel(TextLabel):
     """A richtext label that elides its display"""
 
-    def __init__(self, parent=None):
-        super().__init__(parent=parent, open_external_links=True)
+    def __init__(self, selectable=True, parent=None):
+        super().__init__(selectable=selectable, open_external_links=True, parent=parent)
         self.setTextFormat(Qt.RichText)
